@@ -21,42 +21,26 @@
 
 template<typename T1>
 inline
-bool
-chol(Mat<typename T1::elem_type>& out, const Base<typename T1::elem_type,T1>& X)
+const Op<T1, op_chol>
+chol(const Base<typename T1::elem_type,T1>& X)
   {
   arma_extra_debug_sigprint();
   
-  typedef typename T1::elem_type eT;
-  
-  const unwrap_check<T1> tmp(X.get_ref(), out);
-  const Mat<eT>&     A = tmp.M;
-  
-  arma_debug_check( (A.is_square() == false), "chol(): given matrix is not square");
-  
-  return auxlib::chol(out, A);
+  return Op<T1, op_chol>(X.get_ref());
   }
 
 
 
 template<typename T1>
 inline
-Mat<typename T1::elem_type>
-chol(const Base<typename T1::elem_type,T1>& X)
+bool
+chol(Mat<typename T1::elem_type>& out, const Base<typename T1::elem_type,T1>& X)
   {
   arma_extra_debug_sigprint();
   
-  typedef typename T1::elem_type eT;
+  out = chol(X);
   
-  Mat<eT> out;
-  
-  const bool ok = chol(out, X);
-  
-  if(ok == false)
-    {
-    arma_print("chol(): matrix factorisation failed");
-    }
-  
-  return out;
+  return (out.n_elem == 0) ? false : true;
   }
 
 
